#include <iolpc2103.h>
#include "interrupts.h"
#include "led.h"
#include "bits.h"
#include "rtc.h"
#include "system.h"
#include "uart.h"
#include <inarm.h>




// simple delay
void Delay (unsigned long a) { while (--a!=0); }


// loop cycle
unsigned int i = 0;
// echo
unsigned char ch0 = 0;

// button variable - single click
unsigned char press_but = 1;


/**** INTERRUPTS HANDLERS ****/
// IRQ interrupt handler.
#pragma vector=0x18
__irq __arm void IRQ_ISR_Handler (void)
{
  void (*interrupt_function)();
  unsigned int vector;

  // Called at 1000 Hz rate.
  vector = VICVectAddr; // Get interrupt vector.
  interrupt_function = (void(*)())vector;
  (*interrupt_function)(); // Call vectored interrupt function.

  VICVectAddr = 0; // Clear interrupt in VIC.
}


void RTCInterrupt()
{
  (*RTC_function)();
}



void rtc_int()
{
  Led1Blink();
  //UART0WriteChar(SEC/10+48);
  //UART0WriteChar(SEC%10+48);
  ILR=0x3;      // clear all interrupt of RTC
}



int main()
{

  // InitFreq
  FreqInit();

  // UART initialization
  UART0Initialize(9600);

  Delay(10000);
  UART0WriteTxt("\n\rwww.olimex.com");

  // Init RTC
  InitRTC();

  // Init led
  LedInit();



  /**** INTERRUPTS ****/
  #ifdef RAM
    MEMMAP = 2;                         //This will move the exception vectors in place.
  #else
    MEMMAP = 1;                         //This will move the exception vectors in place.
  #endif


  __disable_interrupt();              //Disable interrupts.
  InitRTCInterrupt(rtc_int);          //Setup interrupt controller.
  __enable_interrupt();               //Enable interrupts.


  //BUT as input
  IODIR_bit.P0_15 = 0;



  while(1) {

    // echo for UART0
    ch0 = UART0ReadChar_nostop();
    if(ch0!=0) {
      UART0WriteChar(ch0);
      UART0WriteChar('*');
    }

    // if button is pressed
    if((!IOPIN_bit.P0_15)&&(press_but==1)) {
      Delay(1000);
      press_but = 0;
      UART0WriteChar('+');
    }
    if((IOPIN_bit.P0_15)&&(press_but==0)) {
      Delay(1000);
      press_but = 1;
    }
  }

}

